==> estateplat-common-1.2.4-20190919.072609-183-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwzl.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import javax.persistence.Table;

@Table(name = "BDC_FWZL")
public class BdcFwzl extends QllxParent implements QllxVo {
    private String dw;//单位
    private String zxywh;//注销业务号
    private Date zxdjsj;//注销登记时间
    private Date zxdbr;//注销登簿人
    private String zxyy;//注销原因
    private Date zlksqx;//租赁开始期限
    private Date zljsqx;//租赁结束期限
    private String fj;//附记
    private String bz;//备注
    private Date zlxysdsj;//租赁协议送达时间
    private String zlbf;//租赁部位
    private String zlfs;//租赁方式（1:直租,2:转租）
    private String zllx;//租赁类型(1:整租,2:合租)
    private Double yzj;//月租金
    private String fwzlbazmh;//房屋租赁备案证明号
    private String nf;//年份
    private Integer lsh;//流水号
    private Double zlmj;//租赁面积

    public String getZlbf() {
        return zlbf;
    }

    public void setZlbf(String zlbf) {
        this.zlbf = zlbf;
    }

    public String getZlfs() {
        return zlfs;
    }

    public void setZlfs(String zlfs) {
        this.zlfs = zlfs;
    }

    public String getZllx() {
        return zllx;
    }

    public void setZllx(String zllx) {
        this.zllx = zllx;
    }

    public Double getYzj() {
        return yzj;
    }

    public void setYzj(Double yzj) {
        this.yzj = yzj;
    }

    public String getFwzlbazmh() {
        return fwzlbazmh;
    }

    public void setFwzlbazmh(String fwzlbazmh) {
        this.fwzlbazmh = fwzlbazmh;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public Integer getLsh() {
        return lsh;
    }

    public void setLsh(Integer lsh) {
        this.lsh = lsh;
    }

    public Double getZlmj() {
        return zlmj;
    }

    public void setZlmj(Double zlmj) {
        this.zlmj = zlmj;
    }
    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public Date getZxdjsj() {
        return zxdjsj;
    }

    public void setZxdjsj(Date zxdjsj) {
        this.zxdjsj = zxdjsj;
    }

    public Date getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(Date zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public Date getZlksqx() {
        return zlksqx;
    }

    public void setZlksqx(Date zlksqx) {
        this.zlksqx = zlksqx;
    }

    public Date getZljsqx() {
        return zljsqx;
    }

    public void setZljsqx(Date zljsqx) {
        this.zljsqx = zljsqx;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getZlxysdsj() {
        return zlxysdsj;
    }

    public void setZlxysdsj(Date zlxysdsj) {
        this.zlxysdsj = zlxysdsj;
    }
}

==> estateplat-common-1.2.4-20220315.013728-984-sources.jar: cn/gtmap/estateplat/model/server/core/BdcFwzl.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;
import javax.persistence.Table;

@Table(name = "BDC_FWZL")
public class BdcFwzl extends QllxParent implements QllxVo {
    private String dw;//单位
    private String zxywh;//注销业务号
    private Date zxdjsj;//注销登记时间
    private String zxdbr;//注销登簿人
    private String zxyy;//注销原因
    private Date zlksqx;//租赁开始期限
    private Date zljsqx;//租赁结束期限
    private String fj;//附记
    private String bz;//备注
    private Date zlxysdsj;//租赁协议送达时间
    private String zlbf;//租赁部位
    private String zlfs;//租赁方式（1:直租,2:转租）
    private String zllx;//租赁类型(1:整租,2:合租)
    private Double yzj;//月租金
    private String fwzlbazmh;//房屋租赁备案证明号
    private String nf;//年份
    private Integer lsh;//流水号
    private Double zlmj;//租赁面积

    public String getZlbf() {
        return zlbf;
    }

    public void setZlbf(String zlbf) {
        this.zlbf = zlbf;
    }

    public String getZlfs() {
        return zlfs;
    }

    public void setZlfs(String zlfs) {
        this.zlfs = zlfs;
    }

    public String getZllx() {
        return zllx;
    }

    public void setZllx(String zllx) {
        this.zllx = zllx;
    }

    public Double getYzj() {
        return yzj;
    }

    public void setYzj(Double yzj) {
        this.yzj = yzj;
    }

    public String getFwzlbazmh() {
        return fwzlbazmh;
    }

    public void setFwzlbazmh(String fwzlbazmh) {
        this.fwzlbazmh = fwzlbazmh;
    }

    public String getNf() {
        return nf;
    }

    public void setNf(String nf) {
        this.nf = nf;
    }

    public Integer getLsh() {
        return lsh;
    }

    public void setLsh(Integer lsh) {
        this.lsh = lsh;
    }

    public Double getZlmj() {
        return zlmj;
    }

    public void setZlmj(Double zlmj) {
        this.zlmj = zlmj;
    }
    public String getDw() {
        return dw;
    }

    public void setDw(String dw) {
        this.dw = dw;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }

    public Date getZxdjsj() {
        return zxdjsj;
    }

    public void setZxdjsj(Date zxdjsj) {
        this.zxdjsj = zxdjsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public Date getZlksqx() {
        return zlksqx;
    }

    public void setZlksqx(Date zlksqx) {
        this.zlksqx = zlksqx;
    }

    public Date getZljsqx() {
        return zljsqx;
    }

    public void setZljsqx(Date zljsqx) {
        this.zljsqx = zljsqx;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public Date getZlxysdsj() {
        return zlxysdsj;
    }

    public void setZlxysdsj(Date zlxysdsj) {
        this.zlxysdsj = zlxysdsj;
    }
}
